#!/bin/bash
#
# This module gathers diagnostic information about 
# a content hub. It is meant only to be 
# uploaded via the settings tab as a .zip
#--------------------------------------------------

DATE=$(date +'%m/%d/%Y')
DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" &> /dev/null && pwd )"
LOGFILE="${DIR}/diagnostic.log"
LOGGING=1

# Log message to console and file
# MSG is set for chk_f to log 
function log(){
  MSG=$1

  if [ $LOGGING = 1 ]; then
    echo -e "SETUP: $1" | tee -a $LOGFILE
    return
  fi
    
  echo -e "SETUP: $1"
}

# Check for error status in previous command 
function check(){
  if [ "${?}" -ne "0" ]; then
    echo "FAILED: '${MSG}'"
    exit 1
  fi
}

function diagnoseContentHub(){
  log "Starting Content Hub  diagnostic"
  
  log "Getting main drive status"
  sudo dumpe2fs -h /dev/sda1; check 
  
  log "Getting drive list"
  sudo lsblk; check   
  
  log "Getting network info"
  sudo ifconfig; check     
  
  log "Getting nginx status"
  sudo systemctl status nginx; check
  
  log "Getting nginx configuration"
  sudo cat /etc/nginx/sites-available/hub.nginx.conf; check 
  
  log "Getting for content hub sock file"
  sudo ls /tmp | grep contenthub.sock; check
  
  log "Getting celeryd status"
  sudo sudo systemctl status celeryd; check
  
  log "Getting uwsgi status"
  sudo sudo systemctl status uwsgi; check
  
  log "Getting content hub server log"
  log "=============================="
  sudo cat /srv/easyconnect/logs/django.log; check
  
  log "Finished Content Hub Diagnostic"
}

diagnoseContentHub

